==> saga_2.1.0+dfsg.orig.tar.gz: saga-2.1.0+dfsg/src/modules/grid/grid_tools/Grid_ThresholdBuffer.h <==
/**********************************************************
 * Version $Id: Grid_ThresholdBuffer.h 1246 2011-11-25 13:42:38Z oconrad $
 *********************************************************/
/*******************************************************************************
    ThresholdBuffer.h
    Copyright (C) Victor Olaya
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*******************************************************************************/ 

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "MLB_Interface.h"

class CThresholdBuffer : public CSG_Module_Grid {

private:

	CSG_Grid* m_pFeatures; 
	CSG_Grid* m_pBuffer;
	CSG_Grid* m_pValueGrid;
	CSG_Grid* m_pThresholdGrid;
	double m_dThreshold;
	int m_iThresholdType;
//	CAPI_3D_iPoints	m_pCentralPoints;
//	CAPI_3D_iPoints	m_pAdjPoints;
	CSG_Points_Int	m_pCentralPoints;
	CSG_Points_Int	m_pAdjPoints;
	
	void BufferPoint(int,int);

public:

	CThresholdBuffer(void);
	virtual ~CThresholdBuffer(void);

	virtual CSG_String		Get_MenuPath	(void)	{	return( _TL("R:Buffers") );	}

protected:
	virtual bool On_Execute(void);

};

==> saga_2.1.1.tar.gz: saga-2.1.1/src/modules/grid/grid_tools/Grid_ThresholdBuffer.h <==
/**********************************************************
 * Version $Id: Grid_ThresholdBuffer.h 1891 2013-12-04 17:50:43Z oconrad $
 *********************************************************/
/*******************************************************************************
    ThresholdBuffer.h
    Copyright (C) Victor Olaya
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*******************************************************************************/ 

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "MLB_Interface.h"

class CThresholdBuffer : public CSG_Module_Grid
{
public:
	CThresholdBuffer(void);
	virtual ~CThresholdBuffer(void);

	virtual CSG_String			Get_MenuPath			(void)	{	return( _TL("A:Grid|Distances") );	}


protected:

	virtual bool				On_Execute				(void);


private:

	int							m_iThresholdType;

	double						m_dThreshold;

	CSG_Grid					*m_pFeatures, *m_pBuffer, *m_pValueGrid, *m_pThresholdGrid;

	CSG_Points_Int				m_pCentralPoints, m_pAdjPoints;


	void						BufferPoint				(int x, int y);

};
